pub struct GeneratedSchemaBundleV1 {
pub schema_version: String,
pub generated_schema_bundle_id: GeneratedSchemaBundleId,
pub spec_bundle_id: SpecBundleId,
pub normative_ast_id: NormativeAstId,
pub proof_obligation_set_id: ProofObligationSetId,
pub schema_family: String,
pub generated_files: Vec<GeneratedSchemaFileV1>,
pub admission_state: GeneratedAdmissionState,
pub advisory_only: bool,
pub generated_at: String,
}Fields
schema_version: Stringgenerated_schema_bundle_id: GeneratedSchemaBundleIdspec_bundle_id: SpecBundleIdnormative_ast_id: NormativeAstIdproof_obligation_set_id: ProofObligationSetIdschema_family: Stringgenerated_files: Vec<GeneratedSchemaFileV1>admission_state: GeneratedAdmissionStateadvisory_only: boolgenerated_at: StringTrait Implementations
Sourceimpl Clone for GeneratedSchemaBundleV1
impl Clone for GeneratedSchemaBundleV1
Sourcefn clone(&self) -> GeneratedSchemaBundleV1
fn clone(&self) -> GeneratedSchemaBundleV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GeneratedSchemaBundleV1
impl Debug for GeneratedSchemaBundleV1
Sourceimpl<'de> Deserialize<'de> for GeneratedSchemaBundleV1
impl<'de> Deserialize<'de> for GeneratedSchemaBundleV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for GeneratedSchemaBundleV1
Sourceimpl JsonSchema for GeneratedSchemaBundleV1
impl JsonSchema for GeneratedSchemaBundleV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for GeneratedSchemaBundleV1
impl PartialEq for GeneratedSchemaBundleV1
Sourcefn eq(&self, other: &GeneratedSchemaBundleV1) -> bool
fn eq(&self, other: &GeneratedSchemaBundleV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for GeneratedSchemaBundleV1
impl Serialize for GeneratedSchemaBundleV1
impl StructuralPartialEq for GeneratedSchemaBundleV1