pub struct HumanVetoBundleV1 {
pub schema_version: String,
pub human_veto_bundle_id: HumanVetoBundleId,
pub generated_schema_bundle_id: GeneratedSchemaBundleId,
pub reason: String,
}Fields
schema_version: Stringhuman_veto_bundle_id: HumanVetoBundleIdgenerated_schema_bundle_id: GeneratedSchemaBundleIdreason: StringTrait Implementations
Sourceimpl Clone for HumanVetoBundleV1
impl Clone for HumanVetoBundleV1
Sourcefn clone(&self) -> HumanVetoBundleV1
fn clone(&self) -> HumanVetoBundleV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HumanVetoBundleV1
impl Debug for HumanVetoBundleV1
Sourceimpl<'de> Deserialize<'de> for HumanVetoBundleV1
impl<'de> Deserialize<'de> for HumanVetoBundleV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for HumanVetoBundleV1
Sourceimpl JsonSchema for HumanVetoBundleV1
impl JsonSchema for HumanVetoBundleV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for HumanVetoBundleV1
impl PartialEq for HumanVetoBundleV1
Sourcefn eq(&self, other: &HumanVetoBundleV1) -> bool
fn eq(&self, other: &HumanVetoBundleV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for HumanVetoBundleV1
impl Serialize for HumanVetoBundleV1
impl StructuralPartialEq for HumanVetoBundleV1