pub struct MetaChallengeBundleV1 {
pub schema_version: String,
pub meta_challenge_bundle_id: MetaChallengeBundleId,
pub generated_schema_bundle_id: GeneratedSchemaBundleId,
pub challenge_summary: String,
pub horizon_only: bool,
}Fields
schema_version: Stringmeta_challenge_bundle_id: MetaChallengeBundleIdgenerated_schema_bundle_id: GeneratedSchemaBundleIdchallenge_summary: Stringhorizon_only: boolTrait Implementations
Sourceimpl Clone for MetaChallengeBundleV1
impl Clone for MetaChallengeBundleV1
Sourcefn clone(&self) -> MetaChallengeBundleV1
fn clone(&self) -> MetaChallengeBundleV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MetaChallengeBundleV1
impl Debug for MetaChallengeBundleV1
Sourceimpl<'de> Deserialize<'de> for MetaChallengeBundleV1
impl<'de> Deserialize<'de> for MetaChallengeBundleV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for MetaChallengeBundleV1
Sourceimpl JsonSchema for MetaChallengeBundleV1
impl JsonSchema for MetaChallengeBundleV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MetaChallengeBundleV1
impl PartialEq for MetaChallengeBundleV1
Sourcefn eq(&self, other: &MetaChallengeBundleV1) -> bool
fn eq(&self, other: &MetaChallengeBundleV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for MetaChallengeBundleV1
impl Serialize for MetaChallengeBundleV1
impl StructuralPartialEq for MetaChallengeBundleV1