pub struct NormativeASTV1 {
pub schema_version: String,
pub normative_ast_id: NormativeAstId,
pub spec_bundle_id: SpecBundleId,
pub nodes: Vec<NormativeAstNodeV1>,
pub publication_status: SurfaceStatus,
}Fields
schema_version: Stringnormative_ast_id: NormativeAstIdspec_bundle_id: SpecBundleIdnodes: Vec<NormativeAstNodeV1>publication_status: SurfaceStatusTrait Implementations
Sourceimpl Clone for NormativeASTV1
impl Clone for NormativeASTV1
Sourcefn clone(&self) -> NormativeASTV1
fn clone(&self) -> NormativeASTV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NormativeASTV1
impl Debug for NormativeASTV1
Sourceimpl<'de> Deserialize<'de> for NormativeASTV1
impl<'de> Deserialize<'de> for NormativeASTV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for NormativeASTV1
Sourceimpl JsonSchema for NormativeASTV1
impl JsonSchema for NormativeASTV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for NormativeASTV1
impl PartialEq for NormativeASTV1
Sourcefn eq(&self, other: &NormativeASTV1) -> bool
fn eq(&self, other: &NormativeASTV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for NormativeASTV1
impl Serialize for NormativeASTV1
impl StructuralPartialEq for NormativeASTV1