pub struct ProofEvaluationReceiptV1 {
pub schema_version: String,
pub proof_evaluation_receipt_id: ProofEvaluationReceiptId,
pub proof_obligation_set_id: ProofObligationSetId,
pub generated_schema_bundle_id: Option<GeneratedSchemaBundleId>,
pub satisfied_count: usize,
pub unsatisfied_blocking_obligations: Vec<String>,
pub admission_allowed: bool,
pub advisory_only: bool,
pub evaluated_at: String,
}Fields
schema_version: Stringproof_evaluation_receipt_id: ProofEvaluationReceiptIdproof_obligation_set_id: ProofObligationSetIdgenerated_schema_bundle_id: Option<GeneratedSchemaBundleId>satisfied_count: usizeunsatisfied_blocking_obligations: Vec<String>admission_allowed: booladvisory_only: boolevaluated_at: StringTrait Implementations
Sourceimpl Clone for ProofEvaluationReceiptV1
impl Clone for ProofEvaluationReceiptV1
Sourcefn clone(&self) -> ProofEvaluationReceiptV1
fn clone(&self) -> ProofEvaluationReceiptV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProofEvaluationReceiptV1
impl Debug for ProofEvaluationReceiptV1
Sourceimpl<'de> Deserialize<'de> for ProofEvaluationReceiptV1
impl<'de> Deserialize<'de> for ProofEvaluationReceiptV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ProofEvaluationReceiptV1
Sourceimpl JsonSchema for ProofEvaluationReceiptV1
impl JsonSchema for ProofEvaluationReceiptV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProofEvaluationReceiptV1
impl PartialEq for ProofEvaluationReceiptV1
Sourcefn eq(&self, other: &ProofEvaluationReceiptV1) -> bool
fn eq(&self, other: &ProofEvaluationReceiptV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProofEvaluationReceiptV1
impl Serialize for ProofEvaluationReceiptV1
impl StructuralPartialEq for ProofEvaluationReceiptV1