pub struct ProofObligationSetV1 {
pub schema_version: String,
pub proof_obligation_set_id: ProofObligationSetId,
pub spec_bundle_id: SpecBundleId,
pub normative_ast_id: NormativeAstId,
pub obligations: Vec<ProofObligationV1>,
}Fields
schema_version: Stringproof_obligation_set_id: ProofObligationSetIdspec_bundle_id: SpecBundleIdnormative_ast_id: NormativeAstIdobligations: Vec<ProofObligationV1>Trait Implementations
Sourceimpl Clone for ProofObligationSetV1
impl Clone for ProofObligationSetV1
Sourcefn clone(&self) -> ProofObligationSetV1
fn clone(&self) -> ProofObligationSetV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProofObligationSetV1
impl Debug for ProofObligationSetV1
Sourceimpl<'de> Deserialize<'de> for ProofObligationSetV1
impl<'de> Deserialize<'de> for ProofObligationSetV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ProofObligationSetV1
Sourceimpl JsonSchema for ProofObligationSetV1
impl JsonSchema for ProofObligationSetV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProofObligationSetV1
impl PartialEq for ProofObligationSetV1
Sourcefn eq(&self, other: &ProofObligationSetV1) -> bool
fn eq(&self, other: &ProofObligationSetV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProofObligationSetV1
impl Serialize for ProofObligationSetV1
impl StructuralPartialEq for ProofObligationSetV1