pub struct ProofObligationV1 {
pub obligation_id: String,
pub description: String,
pub satisfied: bool,
pub blocking: bool,
}Fields
obligation_id: Stringdescription: Stringsatisfied: boolblocking: boolTrait Implementations
Sourceimpl Clone for ProofObligationV1
impl Clone for ProofObligationV1
Sourcefn clone(&self) -> ProofObligationV1
fn clone(&self) -> ProofObligationV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProofObligationV1
impl Debug for ProofObligationV1
Sourceimpl<'de> Deserialize<'de> for ProofObligationV1
impl<'de> Deserialize<'de> for ProofObligationV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ProofObligationV1
Sourceimpl JsonSchema for ProofObligationV1
impl JsonSchema for ProofObligationV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProofObligationV1
impl PartialEq for ProofObligationV1
Sourcefn eq(&self, other: &ProofObligationV1) -> bool
fn eq(&self, other: &ProofObligationV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProofObligationV1
impl Serialize for ProofObligationV1
impl StructuralPartialEq for ProofObligationV1