pub struct SelfHostingBuildReceiptV1 {Show 16 fields
pub schema_version: String,
pub self_hosting_build_receipt_id: SelfHostingBuildReceiptId,
pub spec_bundle_id: SpecBundleId,
pub generated_schema_bundle_id: GeneratedSchemaBundleId,
pub generated_interpreter_bundle_id: GeneratedInterpreterBundleId,
pub generated_conformance_corpus_id: GeneratedConformanceCorpusId,
pub generated_migration_plan_id: GeneratedMigrationPlanId,
pub proof_evaluation_receipt_id: ProofEvaluationReceiptId,
pub human_veto_bundle_id: Option<HumanVetoBundleId>,
pub meta_challenge_bundle_id: Option<MetaChallengeBundleId>,
pub governance_state: GeneratedSurfaceGovernanceState,
pub rollback_required: bool,
pub admission_allowed: bool,
pub advisory_only: bool,
pub notes: Vec<String>,
pub generated_at: String,
}Fields
schema_version: Stringself_hosting_build_receipt_id: SelfHostingBuildReceiptIdspec_bundle_id: SpecBundleIdgenerated_schema_bundle_id: GeneratedSchemaBundleIdgenerated_interpreter_bundle_id: GeneratedInterpreterBundleIdgenerated_conformance_corpus_id: GeneratedConformanceCorpusIdgenerated_migration_plan_id: GeneratedMigrationPlanIdproof_evaluation_receipt_id: ProofEvaluationReceiptIdhuman_veto_bundle_id: Option<HumanVetoBundleId>meta_challenge_bundle_id: Option<MetaChallengeBundleId>governance_state: GeneratedSurfaceGovernanceStaterollback_required: booladmission_allowed: booladvisory_only: boolnotes: Vec<String>generated_at: StringTrait Implementations
Sourceimpl Clone for SelfHostingBuildReceiptV1
impl Clone for SelfHostingBuildReceiptV1
Sourcefn clone(&self) -> SelfHostingBuildReceiptV1
fn clone(&self) -> SelfHostingBuildReceiptV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SelfHostingBuildReceiptV1
impl Debug for SelfHostingBuildReceiptV1
Sourceimpl<'de> Deserialize<'de> for SelfHostingBuildReceiptV1
impl<'de> Deserialize<'de> for SelfHostingBuildReceiptV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SelfHostingBuildReceiptV1
Sourceimpl JsonSchema for SelfHostingBuildReceiptV1
impl JsonSchema for SelfHostingBuildReceiptV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SelfHostingBuildReceiptV1
impl PartialEq for SelfHostingBuildReceiptV1
Sourcefn eq(&self, other: &SelfHostingBuildReceiptV1) -> bool
fn eq(&self, other: &SelfHostingBuildReceiptV1) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SelfHostingBuildReceiptV1