pub struct SpecBundleV1 {
pub schema_version: String,
pub spec_bundle_id: SpecBundleId,
pub spec_name: String,
pub canonical_owner: String,
pub publication_status: SurfaceStatus,
}Fields
schema_version: Stringspec_bundle_id: SpecBundleIdspec_name: Stringcanonical_owner: Stringpublication_status: SurfaceStatusTrait Implementations
Sourceimpl Clone for SpecBundleV1
impl Clone for SpecBundleV1
Sourcefn clone(&self) -> SpecBundleV1
fn clone(&self) -> SpecBundleV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SpecBundleV1
impl Debug for SpecBundleV1
Sourceimpl<'de> Deserialize<'de> for SpecBundleV1
impl<'de> Deserialize<'de> for SpecBundleV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SpecBundleV1
Sourceimpl JsonSchema for SpecBundleV1
impl JsonSchema for SpecBundleV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SpecBundleV1
impl PartialEq for SpecBundleV1
Sourcefn eq(&self, other: &SpecBundleV1) -> bool
fn eq(&self, other: &SpecBundleV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SpecBundleV1
impl Serialize for SpecBundleV1
impl StructuralPartialEq for SpecBundleV1